@@ -11,7 +11,7 @@ package UTF8::R2;
 use 5.00503;    # Universal Consensus 1998 for primetools
 # use 5.008001; # Lancaster Consensus 2013 for toolchains
 
-$VERSION = '0.13';
+$VERSION = '0.14';
 $VERSION = $VERSION;
 
 use strict;
@@ -885,7 +885,8 @@ sub UTF8::R2::ucfirst {
 # syntax sugar for UTF-8 codepoint regex
 #
 # tie my %mb, 'UTF8::R2';
-# $result = $_ =~ $mb{qr/$utf8regex/imsxogc}
+# $result = $_ =~ $mb{qr/$utf8regex/imsxo}
+# $result = $_ =~ m<\G$mb{qr/$utf8regex/imsxo}>gc
 # $result = $_ =~ s<$mb{qr/before/imsxo}><after>egr
 
 sub TIEHASH  { bless { }, $_[0] }
@@ -977,8 +978,8 @@ name.
                           m<@{[UTF8::R2::qr(qr/$utf8regex/imsxo)]}>gc
                             or                                       not supports named character (such as \N{GREEK SMALL LETTER EPSILON}, \N{greek:epsilon}, or \N{epsilon})
                           use UTF8::R2 qw(%mb);                      not supports character properties (like \p{PROP} and \P{PROP})
-                          $mb{qr/$utf8regex/imsxo}
-                          m<\G$mb{qr/$utf8regex/imsxo}>gc
+                          $mb{qr/$utf8regex/imsxo}                   modifier i, m, s, x, o work on compile time
+                          m<\G$mb{qr/$utf8regex/imsxo}>gc            modifier g,c work on run time
 
                           Special Escapes in Regex                   Support Perl Version
                           --------------------------------------------------------------------------------------------------
@@ -994,7 +995,7 @@ name.
                           $mb{qr/ \V /}                              since perl 5.010
                           $mb{qr/ \R /}                              since perl 5.010
                           $mb{qr/ \N /}                              since perl 5.012
-
+                          (max \x{UTF8hex} is \x{7FFFFFFF})
   ------------------------------------------------------------------------------------------------------------------------------------------
   ?? or m??                 (nothing)
   ------------------------------------------------------------------------------------------------------------------------------------------
